# scsk_dx_utils
utils for SCSK Europe DX data team

# resources
https://packaging.python.org/en/latest/tutorials/packaging-projects/

# PYPI credentials
user: emelas
password: SCSKDXLondon

# pip page
https://pypi.org/project/SCSKutils/

## to install:
pip install SCSKutils
